@@ -32,9 +32,9 @@ def restart_iface(ifname=None, sleep=5):
     '''Restart the specified network interface. Returns True if restarted without error.'''
     logger.info("Restarting Interface")
     subprocess.run(
-        'ifdown {} --force && sleep {}'.format(ifname, sleep),
+        ['ifdown', ifname, '--force', '&&', 'sleep', str(sleep)],
         check=True, stderr=sys.stderr)
     subprocess.run(
-        'ifup {} && sleep {}'.format(ifname, sleep),
+        ['ifup', ifname, '&&', 'sleep', str(sleep)],
         check=True, stderr=sys.stderr)
     return True
